@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package DAIA::Object;
 {
-  $DAIA::Object::VERSION = '0.41';
+  $DAIA::Object::VERSION = '0.42';
 }
 #ABSTRACT: Abstract base class of all DAIA classes
 
@@ -11,8 +11,7 @@ use Carp::Clan;
 use CGI; # TODO: allow other kind of CGI
 use Data::Validate::URI qw(is_uri is_web_uri);
 use IO::Scalar;
-use Scalar::Util qw(refaddr);
-use UNIVERSAL 'isa';
+use Scalar::Util qw(refaddr reftype);
 use JSON;
 
 our $AUTOLOAD;
@@ -97,7 +96,7 @@ sub xml {
 
     my $xmlns = $param{xmlns} || ($param{xslt} or $param{header});
     my $pi = $param{pi} || [ ];
-    $pi = [$pi] unless isa($pi,'ARRAY');
+    $pi = [$pi] unless (reftype($pi) || '') eq 'ARRAY';
 
     push @$pi, 'xml-stylesheet type="text/xsl" href="' . xml_escape_value($param{xslt}) . '"'
         if $param{xslt};
@@ -274,6 +273,8 @@ sub AUTOLOAD {
 
     my $opt = $PROPERTIES->{$property};
 
+    # TODO: conflicting properties?
+    
     if ( $method =~ /^add/ ) {
         croak "$class->$property is not repeatable or has no type"
             unless $opt->{repeatable} and $opt->{type};
@@ -456,14 +457,10 @@ sub _enable_utf8_layer {
     binmode $fh, ':encoding(UTF-8)';
 }
 
-
 our %COMMON_PROPERTIES =( 
     id => {
         filter => sub { my $v = "$_[0]"; $v =~ s/^\s+|\s$//g; is_uri($v) ? $v : undef; }
     },
-#    href => {
-#        filter => sub { my $v = "$_[0]"; $v =~ s/^\s+|\s$//g; is_web_uri($v) ? $v : undef; }
-#    },
     href => { 
         filter => sub { my $v = "$_[0]"; is_web_uri($v) ? $v : undef; },
         predicate => 'http://xmlns.com/foaf/0.1/page',
@@ -487,7 +484,7 @@ DAIA::Object - Abstract base class of all DAIA classes
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 DESCRIPTION
 
